@@ -3,7 +3,7 @@
 
 
 __author__  = "ChenyangGao <https://chenyanggao.github.io>"
-__all__ = ["escape", "translate", "parse", "read_file", "read_str", "ignore"]
+__all__ = ["escape", "translate", "parse", "read_file", "read_str", "predicate"]
 
 from fnmatch import translate as wildcard_translate
 from glob import escape
@@ -38,12 +38,12 @@ def make_mimetype_predicate(pattern: str, /) -> Optional[Callable]:
     match first:
         case "=":
             return rest.__eq__
-        case "~":
-            return methodcaller("__contains__", rest)
         case "^":
             return methodcaller("startswith", rest)
         case "$":
             return methodcaller("endswith", rest)
+        case ":":
+            return methodcaller("__contains__", rest)
         case ";":
             return lambda s, needle=rest: needle in s.split()
         case ",":
@@ -54,12 +54,12 @@ def make_mimetype_predicate(pattern: str, /) -> Optional[Callable]:
             return re_compile(re_escape(rest)+r"\b").search
         case "|":
             return re_compile(r"\b"+re_escape(rest)+r"\b").search
-        case "*":
-            return re_compile(wildcard_translate(rest)).fullmatch
-        case "/":
+        case "~":
             return re_compile(rest).search
-        case "%":
+        case "-":
             return re_compile(rest).fullmatch
+        case "%":
+            return re_compile(wildcard_translate(rest)).fullmatch
         case _:
             return pattern.__eq__
 
@@ -91,7 +91,7 @@ def parse(
                 else:
                     ignores.append(pattern)
         elif check_mimetype and pattern.removeprefix("!").startswith(
-            ("=", "~", "^", "$", ";", ",", "<", ">", "|", "*", "/", "%")
+            ("=", "^", "$", ":", ";", ",", "<", ">", "|", "~", "-", "%")
         ):
             predicate = make_mimetype_predicate(pattern.removeprefix("!"))
             if predicate:
@@ -120,7 +120,7 @@ def parse(
     preds: list[Callable] = []
     if check_mimetype and (mimetype_shows or mimetype_ignores):
         def predicate(path: str, /):
-            if path.startswith("/"):
+            if path.endswith("/"):
                 return False
             mime = guess_type(path)[0] or "application/octet-stream"
             return not any(p(mime) for p in mimetype_shows) and any(p(mime) for p in mimetype_ignores)
@@ -149,7 +149,7 @@ def read_file(file: bytes | str | PathLike | TextIO, /) -> list[str]:
 
 
 def read_str(s: str, /) -> list[str]:
-    return [p for p in CRE_PAT_IN_STR.findall(s) if p]
+    return [p.replace(r"\ ", " ") for p in CRE_PAT_IN_STR.findall(s) if p]
 
 
 def predicate(
